<?php
// wbb imports
require_once(WBB_DIR.'lib/data/boxes/PortalBox.class.php');
require_once(WBB_DIR.'lib/data/boxes/PortalHelpers.class.php');
require_once(WBB_DIR.'lib/data/boxes/StandardPortalBox.class.php');

/**
 * This box shows the current buddies of the user
 *
 * @package	com.woltlab.community.portal.buddies
 * @author	WoltLab Community
 * @copyright	2009-2010 WoltLab Community
 * @license	GNU Lesser Public License <http://www.gnu.org/licenses/lgpl.html>
 * @subpackage	data.boxes
 * @category	Portal
 */
class BuddiesBox extends PortalBox implements StandardPortalBox {
	public $stylesheet = 'buddies';
	public $buddies = array();
	public $invitedBuddies = array();

	/**
	 * @see StandardPortalBox::readData()
	 */
	public function readData() {
		$sqlConditions = '';

		if (!WCF::getUser()->userID) {
			$this->empty = true;
			return;
		}
				
		// get users online
		$usersOnline = (PORTAL_COMPATIBILITY_MODE) ? array() : PortalHelpers::getUsersOnlineList();

		// filter by userID if offline buddies should not be shown
		if (!WCF::getUser()->buddiesboxshowoffline && !PORTAL_COMPATIBILITY_MODE) {
			// skip if only online users should be displayed, but no user is online or visible
			if (empty($usersOnline)) {
				$this->empty = true;
				return;
			}

			$userIDs = array_keys($usersOnline);
			$sqlConditions .= " AND user.userID IN (".implode(',', $userIDs).")";
		}

		// skip invitations
		if (!WCF::getUser()->buddiesboxshowinvited) {
			$sqlConditions .= " AND whitelist.confirmed = 1";
		}

		// get buddies
		$sql = "SELECT		user.userID, user.username, whitelist.confirmed
			FROM		wcf".WCF_N."_user_whitelist whitelist
			LEFT JOIN	wcf".WCF_N."_user user
			ON		(user.userID = whitelist.whiteUserID)
			WHERE 		whitelist.userID = ".WCF::getUser()->userID."
					".$sqlConditions."
			ORDER BY 	user.username";
		$result = WCF::getDB()->sendQuery($sql);

		while ($row = WCF::getDB()->fetchArray($result)) {
			// mark online users
			$row['isOnline'] = (array_key_exists($row['userID'], $usersOnline)) ? true : false;

			if ($row['confirmed']) {
				$this->buddies[] = $row;
			}
			else {
				$this->invitedBuddies[] = $row;
			}
		}

		if (empty($this->buddies) && empty($this->invitedBuddies)) $this->empty = true;
	}

	/**
	 * @see StandardPortalBox::getTemplateName()
	 */
	public function getTemplateName() {
		return 'buddiesBox';
	}
}
?>